/// <reference types="react" />
import * as _material_ui_core from '@material-ui/core';
import * as react from 'react';
import react__default, { PropsWithChildren, ComponentProps } from 'react';
import * as _tanstack_react_query from '@tanstack/react-query';
import { QueryClient, UseQueryResult } from '@tanstack/react-query';
import * as valibot from 'valibot';
import { Output } from 'valibot';
import * as _backstage_core_plugin_api from '@backstage/core-plugin-api';

type CoderAuthProviderProps = Readonly<PropsWithChildren<unknown>>;
declare const CoderAuthProvider: ({ children }: CoderAuthProviderProps) => react__default.JSX.Element;

declare const yamlConfigSchema: valibot.UnionSchema<(valibot.UndefinedSchema<undefined> | valibot.ObjectSchema<{
    templateName: valibot.OptionalSchema<valibot.StringSchema<string>, undefined, string | undefined>;
    mode: valibot.OptionalSchema<valibot.UnionSchema<(valibot.LiteralSchema<"manual", "manual"> | valibot.LiteralSchema<"auto", "auto">)[], "manual" | "auto">, undefined, "manual" | "auto" | undefined>;
    params: valibot.OptionalSchema<valibot.RecordSchema<valibot.StringSchema<string>, valibot.UnionSchema<(valibot.StringSchema<string> | valibot.UndefinedSchema<undefined>)[], string | undefined>, {
        [x: string]: string | undefined;
    }>, undefined, {
        [x: string]: string | undefined;
    } | undefined>;
}, undefined, {
    templateName?: string | undefined;
    mode?: "manual" | "auto" | undefined;
    params?: {
        [x: string]: string | undefined;
    } | undefined;
}>)[], {
    templateName?: string | undefined;
    mode?: "manual" | "auto" | undefined;
    params?: {
        [x: string]: string | undefined;
    } | undefined;
} | undefined>;
type YamlConfig = Output<typeof yamlConfigSchema>;
/**
 * Provides a cleaned and pre-processed version of all repo data that can be
 * sourced from CoderAppConfig and any entity data.
 */
type CoderWorkspacesConfig = Readonly<{
    creationUrl: string;
    templateName: string;
    repoUrlParamKeys: readonly string[];
    mode: 'manual' | 'auto';
    params: Record<string, string | undefined>;
    repoUrl: string | undefined;
}>;
type UseCoderWorkspacesConfigOptions = Readonly<{
    readEntityData?: boolean;
}>;
declare function useCoderWorkspacesConfig({ readEntityData, }: UseCoderWorkspacesConfigOptions): CoderWorkspacesConfig;

type CoderAppConfig = Readonly<{
    deployment: Readonly<{
        accessUrl: string;
    }>;
    workspaces: Readonly<Exclude<YamlConfig, undefined> & {
        templateName: string;
        repoUrlParamKeys: readonly [string, ...string[]];
    }>;
}>;
type CoderSettingsProviderProps = Readonly<PropsWithChildren<{
    appConfig: CoderAppConfig;
}>>;
declare const CoderAppConfigProvider: ({ children, appConfig, }: CoderSettingsProviderProps) => react__default.JSX.Element;

type CoderProviderProps = ComponentProps<typeof CoderAuthProvider> & ComponentProps<typeof CoderAppConfigProvider> & {
    queryClient?: QueryClient;
};

type QueryInput = Readonly<{
    coderQuery: string;
    workspacesConfig?: CoderWorkspacesConfig;
}>;
declare function useCoderWorkspacesQuery({ coderQuery, workspacesConfig, }: QueryInput): _tanstack_react_query.UseQueryResult<readonly {
    id: string;
    name: string;
    template_icon: string;
    owner_name: string;
    latest_build: {
        id: string;
        status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
        resources: {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }[];
    };
}[], unknown>;

declare const workspaceSchema: valibot.ObjectSchema<{
    id: valibot.StringSchema<string>;
    name: valibot.StringSchema<string>;
    template_icon: valibot.StringSchema<string>;
    owner_name: valibot.StringSchema<string>;
    latest_build: valibot.ObjectSchema<{
        id: valibot.StringSchema<string>;
        resources: valibot.ArraySchema<valibot.ObjectSchema<{
            id: valibot.StringSchema<string>;
            agents: valibot.OptionalSchema<valibot.ArraySchema<valibot.ObjectSchema<{
                id: valibot.StringSchema<string>;
                status: valibot.UnionSchema<(valibot.LiteralSchema<"connected", "connected"> | valibot.LiteralSchema<"connecting", "connecting"> | valibot.LiteralSchema<"disconnected", "disconnected"> | valibot.LiteralSchema<"timeout", "timeout">)[], "connected" | "connecting" | "disconnected" | "timeout">;
            }, undefined, {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }>, {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[]>, undefined, {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined>;
        }, undefined, {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }>, {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }[]>;
        status: valibot.UnionSchema<(valibot.LiteralSchema<"canceled", "canceled"> | valibot.LiteralSchema<"canceling", "canceling"> | valibot.LiteralSchema<"deleted", "deleted"> | valibot.LiteralSchema<"deleting", "deleting"> | valibot.LiteralSchema<"failed", "failed"> | valibot.LiteralSchema<"pending", "pending"> | valibot.LiteralSchema<"running", "running"> | valibot.LiteralSchema<"starting", "starting"> | valibot.LiteralSchema<"stopped", "stopped"> | valibot.LiteralSchema<"stopping", "stopping">)[], "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping">;
    }, undefined, {
        id: string;
        status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
        resources: {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }[];
    }>;
}, undefined, {
    id: string;
    name: string;
    template_icon: string;
    owner_name: string;
    latest_build: {
        id: string;
        status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
        resources: {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }[];
    };
}>;
type Workspace = Output<typeof workspaceSchema>;

/**
 * @file Wires up all the core logic for passing values down to the
 * sub-components in the same directory.
 *
 * Does not need any tests – test functionality covered by integration tests in
 * CoderWorkspacesCard
 */

type WorkspacesQuery = UseQueryResult<readonly Workspace[]>;
type WorkspacesCardContext = Readonly<{
    queryFilter: string;
    onFilterChange: (newFilter: string) => void;
    workspacesQuery: WorkspacesQuery;
    workspacesConfig: CoderWorkspacesConfig;
    headerId: string;
}>;
declare function useWorkspacesCardContext(): WorkspacesCardContext;

declare const coderPlugin: _backstage_core_plugin_api.BackstagePlugin<{
    root: _backstage_core_plugin_api.RouteRef<undefined>;
}, {}, {}>;
/**
 * All public component exports exposed by the plugin.
 *
 * Make sure that all name properties for each exported component are unique. If
 * there are conflicts, you could run into Backstage compilation issues with no
 * good error messages to help you track down the source.
 */
declare const CoderProvider: ({ children, appConfig, queryClient, }: CoderProviderProps) => react.JSX.Element;
declare const CoderAuthWrapper: ({ children, type }: Readonly<react.PropsWithChildren<{
    type: "card";
}>>) => react.JSX.Element;
declare const CoderErrorBoundary: ({ children, fallbackUi, }: {
    children?: react.ReactNode;
    fallbackUi?: react.ReactNode;
}) => react.JSX.Element;
declare const CoderWorkspacesCard: (props: Omit<Readonly<Omit<react.HTMLAttributes<HTMLDivElement>, "role" | "aria-labelledby"> & {
    queryFilter?: string | undefined;
    defaultQueryFilter?: string | undefined;
    onFilterChange?: ((newFilter: string) => void) | undefined;
    readEntityData?: boolean | undefined;
}>, "children">) => react.JSX.Element;
declare const CoderWorkspacesCardCreateWorkspacesLink: ({ children, className, tooltipRef, target, tooltipText, tooltipProps, ...delegatedProps }: Readonly<react.AnchorHTMLAttributes<HTMLAnchorElement> & {
    tooltipText?: string | undefined;
    tooltipProps?: Omit<_material_ui_core.TooltipProps, "title" | "children"> | undefined;
    tooltipRef?: react.ForwardedRef<unknown> | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardExtraActionsButton: ({ menuProps, buttonRef, toolTipProps, tooltipRef, children, className, onClick: outerOnClick, onClose: outerOnClose, tooltipText, ...delegatedButtonProps }: Readonly<Omit<react.ButtonHTMLAttributes<HTMLButtonElement>, "id" | "aria-controls"> & {
    onClose?: ((event: {}, reason: "backdropClick" | "escapeKeyDown") => void) | undefined;
    buttonRef?: react.ForwardedRef<HTMLButtonElement> | undefined;
    menuProps?: Readonly<Omit<_material_ui_core.MenuProps, "id" | "children" | "open" | "onClose" | "anchorEl" | "MenuListProps" | "getContentAnchorEl"> & {
        MenuListProps: Omit<_material_ui_core.MenuListProps, "aria-describedby" | "aria-labelledby">;
    }> | undefined;
    toolTipProps?: Omit<_material_ui_core.TooltipProps, "title" | "children"> | undefined;
    tooltipText?: string | undefined;
    tooltipRef?: react.ForwardedRef<unknown> | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardHeaderRow: ({ actions, headerLevel, className, headerClassName, hgroupClassName, subheaderClassName, activeRepoFilteringText, headerText, fullBleedLayout, ...delegatedProps }: Readonly<Omit<react.HTMLAttributes<HTMLDivElement>, "children"> & Partial<Record<"headerClassName" | "hgroupClassName" | "subheaderClassName", string>> & {
    headerText?: string | undefined;
    headerLevel?: "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | undefined;
    actions?: react.ReactNode;
    fullBleedLayout?: boolean | undefined;
    activeRepoFilteringText?: react.ReactNode;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardRoot: ({ children, className, queryFilter: outerFilter, onFilterChange: onOuterFilterChange, defaultQueryFilter, readEntityData, ...delegatedProps }: Readonly<Omit<react.HTMLAttributes<HTMLDivElement>, "role" | "aria-labelledby"> & {
    queryFilter?: string | undefined;
    defaultQueryFilter?: string | undefined;
    onFilterChange?: ((newFilter: string) => void) | undefined;
    readEntityData?: boolean | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardSearchBox: ({ className, labelWrapperClassName, searchInputClassName, clearButtonClassName, searchInputRef, clearButtonRef, ...delegatedProps }: Readonly<Omit<react.FieldsetHTMLAttributes<HTMLFieldSetElement>, "children" | "aria-labelledby"> & Partial<Record<"labelWrapperClassName" | "clearButtonClassName" | "searchInputClassName", string>> & {
    searchInputRef?: react.ForwardedRef<HTMLInputElement> | undefined;
    clearButtonRef?: react.ForwardedRef<HTMLButtonElement> | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardWorkspacesList: ({ renderListItem, emptyState, className, listClassName, ordered, fullBleedLayout, ...delegatedProps }: Readonly<Omit<react.HTMLAttributes<HTMLDivElement>, "children"> & {
    emptyState?: react.ReactNode;
    ordered?: boolean | undefined;
    listClassName?: string | undefined;
    fullBleedLayout?: boolean | undefined;
    renderListItem?: ((input: Readonly<{
        workspace: {
            id: string;
            name: string;
            template_icon: string;
            owner_name: string;
            latest_build: {
                id: string;
                status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
                resources: {
                    id: string;
                    agents?: {
                        id: string;
                        status: "connected" | "connecting" | "disconnected" | "timeout";
                    }[] | undefined;
                }[];
            };
        };
        index: number;
        workspaces: readonly {
            id: string;
            name: string;
            template_icon: string;
            owner_name: string;
            latest_build: {
                id: string;
                status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
                resources: {
                    id: string;
                    agents?: {
                        id: string;
                        status: "connected" | "connecting" | "disconnected" | "timeout";
                    }[] | undefined;
                }[];
            };
        }[];
    }>) => react.ReactNode) | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardWorkspacesListIcon: ({ src, workspaceName, className, imageClassName, imageRef, ...delegatedProps }: Readonly<Omit<react.HTMLAttributes<HTMLDivElement>, "children" | "aria-hidden"> & {
    src: string;
    workspaceName: string;
    imageClassName?: string | undefined;
    imageRef?: react.ForwardedRef<HTMLImageElement> | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardWorkspacesListItem: ({ workspace, className, listFlexRowClassName, linkClassName, onlineStatusContainerClassName, onlineStatusLightClassName, buttonClassName, onClick: outerOnClick, onAuxClick: outerOnAuxClick, onKeyDown: outerOnKeyDown, ...delegatedProps }: Readonly<Omit<react.LiHTMLAttributes<HTMLLIElement>, "children"> & Partial<Record<"buttonClassName" | "linkClassName" | "listFlexRowClassName" | "onlineStatusContainerClassName" | "onlineStatusLightClassName", string>> & {
    workspace: {
        id: string;
        name: string;
        template_icon: string;
        owner_name: string;
        latest_build: {
            id: string;
            status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
            resources: {
                id: string;
                agents?: {
                    id: string;
                    status: "connected" | "connecting" | "disconnected" | "timeout";
                }[] | undefined;
            }[];
        };
    };
}>) => react.JSX.Element;

export { CoderAppConfig, CoderAuthWrapper, CoderErrorBoundary, CoderProvider, CoderWorkspacesCard, CoderWorkspacesCardCreateWorkspacesLink, CoderWorkspacesCardExtraActionsButton, CoderWorkspacesCardHeaderRow, CoderWorkspacesCardRoot, CoderWorkspacesCardSearchBox, CoderWorkspacesCardWorkspacesList, CoderWorkspacesCardWorkspacesListIcon, CoderWorkspacesCardWorkspacesListItem, coderPlugin, useCoderWorkspacesConfig, useCoderWorkspacesQuery, useWorkspacesCardContext };
